@@ -31,6 +31,8 @@ var group__spa__names =
     [ "SPA_NAME_API_ALSA_SEQ_SINK", "group__spa__names.html#ga669c4de92ce52f8cd978eafc863733c7", null ],
     [ "SPA_NAME_API_ALSA_SEQ_BRIDGE", "group__spa__names.html#ga2dfd6b7bede9d0057cc3d926a6f6daea", null ],
     [ "SPA_NAME_API_ALSA_ACP_DEVICE", "group__spa__names.html#gae737af4a5b94705cb00880d4e35175d7", null ],
+    [ "SPA_NAME_API_ALSA_COMPRESS_OFFLOAD_DEVICE", "group__spa__names.html#gaa129e32c69913bea70931505835d168a", null ],
+    [ "SPA_NAME_API_ALSA_COMPRESS_OFFLOAD_SINK", "group__spa__names.html#gadc887e81536271d1538500da0fb6be1f", null ],
     [ "SPA_NAME_API_BLUEZ5_ENUM_DBUS", "group__spa__names.html#gaee3c98a88d81eec0d1a68908fed7d7d1", null ],
     [ "SPA_NAME_API_BLUEZ5_DEVICE", "group__spa__names.html#ga6f8c2d1151dab294cd25cb2ff6277441", null ],
     [ "SPA_NAME_API_BLUEZ5_MEDIA_SINK", "group__spa__names.html#ga8eb39736e87cdb644237a55b5d38cf34", null ],
@@ -39,6 +41,8 @@ var group__spa__names =
     [ "SPA_NAME_API_BLUEZ5_A2DP_SOURCE", "group__spa__names.html#ga45fd55853ff79716c7d4dfaa4b004449", null ],
     [ "SPA_NAME_API_BLUEZ5_SCO_SINK", "group__spa__names.html#gab7e9eec4ea4e014db3a9e4b907559ff6", null ],
     [ "SPA_NAME_API_BLUEZ5_SCO_SOURCE", "group__spa__names.html#ga8146eeb0bad2c0312e0e8c71c3d8496f", null ],
+    [ "SPA_NAME_API_BLUEZ5_MIDI_ENUM", "group__spa__names.html#ga38307a0857ead4864fd8fd8b306d2779", null ],
+    [ "SPA_NAME_API_BLUEZ5_MIDI_NODE", "group__spa__names.html#gacffa316f5521c4c5addf2edec39be6d8", null ],
     [ "SPA_NAME_API_CODEC_BLUEZ5_MEDIA", "group__spa__names.html#ga77956282eec82aad57326a661845fec2", null ],
     [ "SPA_NAME_API_V4L2_ENUM_UDEV", "group__spa__names.html#ga63f28346db2b854192c30e714e64f933", null ],
     [ "SPA_NAME_API_V4L2_DEVICE", "group__spa__names.html#gac4ef8bddd1f53a3a890c5ab7bb32db3f", null ],
@@ -51,5 +55,7 @@ var group__spa__names =
     [ "SPA_NAME_API_JACK_SOURCE", "group__spa__names.html#ga11c2cbfdfb9e3c5c6f2567527be11f02", null ],
     [ "SPA_NAME_API_JACK_SINK", "group__spa__names.html#gac2d9defa0b11f106341260bc879a3d91", null ],
     [ "SPA_NAME_API_VULKAN_COMPUTE_SOURCE", "group__spa__names.html#ga191088dbac1ee56122ceb215f16604d5", null ],
-    [ "SPA_NAME_API_VULKAN_COMPUTE_FILTER", "group__spa__names.html#ga4dbc7ed7f81507d09348aa39215f0edb", null ]
+    [ "SPA_NAME_API_VULKAN_COMPUTE_FILTER", "group__spa__names.html#ga4dbc7ed7f81507d09348aa39215f0edb", null ],
+    [ "SPA_NAME_API_VULKAN_BLIT_FILTER", "group__spa__names.html#ga3738db386d94d7a9c3787545f0802593", null ],
+    [ "SPA_NAME_API_VULKAN_BLIT_DSP_FILTER", "group__spa__names.html#ga58de76015844ded3e3c51d3b532a80b2", null ]
 ];
\ No newline at end of file
