@@ -44,28 +44,29 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"alloc_8h.html",
-"group__pw__data__loop.html#ga31fb97e55669c3673f4912ff08fc25f5",
-"group__pw__impl__port.html#ga5682619e17eb12d4bd4c7d70e985e08c",
-"group__pw__loop.html#ga5e937f4e92704c5b7924c07605d06318",
-"group__pw__properties.html#ga7bedc63c78dfe152e866dc518424f299",
-"group__pw__session__manager.html#gacf65a96b2b6cb1f16af259bc667518bd",
-"group__spa__buffer.html#gaeaf6a23eedc8287e462151c68cf392d8",
-"group__spa__graph.html#ga35411dc23f99354fb70e3c298426da7a",
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114",
-"group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba2dca266818c242b100929746f01af7ff",
-"group__spa__param.html#gad0293e0aafd77aba1e85b110450c3f67",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcad275daa367818990fbd7869290282ace",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa5916c4975331ef07c3a0b1a7c54701f5",
-"group__spa__pod.html#ga4af85c705eae32732d08dd70375e6720",
-"group__spa__system.html#ga282e1c96dc3c64fe48b01b93257191a3",
-"page_audio.html",
-"result_8h.html",
-"structpw__endpoint__stream__methods.html#a06d4d4c207f88dd3e87dadee7401b785",
-"structpw__port__info.html#ab8bd7cf30a25d379e02bfc66c5692c64",
-"structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b",
-"structspa__io__segment__video.html#ad9a1cecce33ac8e1c02532188fe51b5f",
-"structspa__pod__pointer.html#a09512c2a62eecc6518a7921d4cb0c2a7"
+"aac-types_8h.html",
+"group__pw__core.html#gae40b2a9bf4e42aac082bf90e37389c02",
+"group__pw__impl__node.html#gaa4f5ea619bcdb70245eef636caf8d88e",
+"group__pw__log.html#ga09b2a40e80e5fefd6e7cb84147a73988",
+"group__pw__port.html#gac245481d75b73061398575ed44ab3e07",
+"group__pw__session__manager.html#ga7dcaf114cea354db4a8f610ed968e2a7",
+"group__spa__ansi.html#gaef43ee57bc72517c30237843d256fabc",
+"group__spa__device.html#ga6d0493b863780697cf564ff4ae297191",
+"group__spa__keys.html#gaec49a8bf593696ff1aa0fc19d561d414",
+"group__spa__node.html#ga7e7c8de3573cd643ee813c35ed254c35",
+"group__spa__param.html#ga6fa558a42ebf277d0fe21e1bee5c1218",
+"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0acd6db5c0aa15b78a301fe9997706906f",
+"group__spa__param.html#gga99c6341a3416bdaacc42f77fc4869821abe20f7c2d9ae0c76b9d6169c84d9669f",
+"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea7be903e8544c911a3d6fa76f4d8286f1",
+"group__spa__pod.html#ga9d02cb79ce7971d17ffaf7875b1abfc7",
+"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a9917f2715796d0cabc77ea3f7db161ac",
+"page_module_access.html",
+"structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21",
+"structpw__impl__link__events.html#a05b20c99f1014e62e0d032b92382f584",
+"structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1",
+"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724",
+"structspa__loop__control__methods.html",
+"structspa__region.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
