@@ -1,5 +1,6 @@
 var NAVTREEINDEX19 =
 {
+"structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1":[8,3,13,1,4],
 "structpw__proxy__events.html#a220d199c1f0a241f1e623686863e8158":[8,3,13,1,6],
 "structpw__proxy__events.html#a25e8553fd0ed2f729ffe61994f6973a2":[8,3,13,1,0],
 "structpw__proxy__events.html#a8072b9d1ea7e1c91cce89de75d1c7e61":[8,3,13,1,3],
@@ -248,6 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__debug__file__ctx.html":[8,7,3,11],
 "structspa__debug__file__ctx.html#a34708c6380f0ca51b9d318a089306401":[8,7,3,11,1],
 "structspa__debug__file__ctx.html#a817d19045e3261030ec8e38842a018c3":[8,7,3,11,0],
-"structspa__debug__log__ctx.html":[8,7,3,12],
-"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724":[8,7,3,12,6]
+"structspa__debug__log__ctx.html":[8,7,3,12]
 };
