@@ -1,5 +1,6 @@
 var NAVTREEINDEX20 =
 {
+"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724":[8,7,3,12,6],
 "structspa__debug__log__ctx.html#a49ae612d5a9f8abff00d338e0f42f338":[8,7,3,12,5],
 "structspa__debug__log__ctx.html#a7834e2a074032895d9760015da193685":[8,7,3,12,1],
 "structspa__debug__log__ctx.html#a7ef044cf8f043c056c0f09e7dc52772f":[8,7,3,12,2],
@@ -248,6 +249,5 @@ var NAVTREEINDEX20 =
 "structspa__loop__control__hooks.html":[8,7,9,4,6],
 "structspa__loop__control__hooks.html#a129526ea88e29db103f01666a32c2d20":[8,7,9,4,6,1],
 "structspa__loop__control__hooks.html#a1d60078aab0c143a082ab30e91151dd2":[8,7,9,4,6,0],
-"structspa__loop__control__hooks.html#a94545cf994d47a1acc84437e5c357141":[8,7,9,4,6,2],
-"structspa__loop__control__methods.html":[8,7,9,4,7]
+"structspa__loop__control__hooks.html#a94545cf994d47a1acc84437e5c357141":[8,7,9,4,6,2]
 };
